package com.isu.gaswellwatch.controller;


import com.isu.gaswellwatch.annotation.OperationLog;
import com.isu.gaswellwatch.entity.Dictionary;
import com.isu.gaswellwatch.entity.Response;
import com.isu.gaswellwatch.enums.LogType;
import com.isu.gaswellwatch.service.DictionaryService;
import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import org.springframework.web.bind.annotation.*;

import java.util.List;


@RestController
@RequestMapping("dictionary")
public class DictionaryController {
    /**
     * 服务对象
     */
    @Resource
    private DictionaryService dictionaryService;


    @PostMapping("/add")
    @OperationLog(description = "新增字典", type = LogType.ADD)
    public Response<String> add(@RequestBody @Valid Dictionary dictionary){
        dictionaryService.add(dictionary);
        return Response.succeed();
    }

    @PostMapping("/edit")
    @OperationLog(description = "修改字典", type = LogType.UPDATE)
    public Response<String> edit(@RequestBody @Valid Dictionary dictionary){
        dictionaryService.edit(dictionary);
        return Response.succeed();
    }

    @GetMapping("/delete")
    @OperationLog(description = "删除字典", type = LogType.DELETE)
    public Response<String> delete(@RequestParam Long id){
        dictionaryService.delete(id);
        return Response.succeed();
    }

    @GetMapping("/getByType")
    public Response<List<Dictionary>> getByType(@RequestParam String type){
        return Response.succeed(dictionaryService.getByType(type));
    }

}

