package com.isu.gaswellwatch.modbus.data.listener;

import lombok.extern.slf4j.Slf4j;
import org.apache.commons.compress.utils.IOUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.amqp.core.BatchMessageListener;
import org.springframework.amqp.core.Message;

import java.io.BufferedWriter;
import java.io.File;
import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.nio.file.StandardOpenOption;
import java.util.List;

/**
 * @author <a href="mailto:scwsl@foxmail.com">王仕龙</a>
 * 2024/11/23 0:47
 */
@Slf4j
public class ModbusMessageBackupListener implements BatchMessageListener {

    @Override
    public void onMessage(Message message) {
        this.onMessageBatch(List.of(message));
    }

    @Override
    public void onMessageBatch(List<Message> messages) {
        File file;
        String messageString, queueName, backupFileName;
        for (Message message : messages) {
            messageString = new String(message.getBody());
            queueName = message.getMessageProperties().getConsumerQueue();
            backupFileName = StringUtils.replace(queueName, "/", "_");
            if (StringUtils.startsWith(backupFileName, "_")) {
                backupFileName = StringUtils.substring(backupFileName, 1);
            }
            backupFileName = "D:\\backup\\modbus\\data\\" + backupFileName + ".data";

            BufferedWriter writer = null;
            try {
                file = new File(backupFileName);
                if (!file.getParentFile().exists()) {
                    file.getParentFile().mkdirs();
                }
                if (!file.exists()) {
                    file.createNewFile();
                }
                writer = Files.newBufferedWriter(Paths.get(backupFileName), StandardCharsets.UTF_8, StandardOpenOption.APPEND);
                writer.write(messageString);
                writer.write("\n");
            } catch (IOException e) {
                log.error("Backup message failed. QueueName {}, Message {}", queueName, messageString, e);
            } finally {
                IOUtils.closeQuietly(writer);
            }
        }
    }

}
